timerelationtools.timespan_2_is_congruent_to_timespan_1
=======================================================

.. autofunction:: abjad.tools.timerelationtools.timespan_2_is_congruent_to_timespan_1.timespan_2_is_congruent_to_timespan_1
   :noindex:
